Node class

Constructors

Node([List<Polygon>? polygons])

Properties

back ↔ Node?
getter/setter pair
front ↔ Node?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
plane ↔ Plane?
getter/setter pair
polygons ↔ List<Polygon>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

allPolygons() → List<Polygon>
build(List<Polygon> polygons) → void
clipPolygons(List<Polygon> polygons) → List<Polygon>
clipTo(Node bsp) → void
clone() → Node
invert() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited