Plane class

Constructors

Plane(Vector3 normal, double w)

Properties

hashCode int
The hash code for this object.
no setterinherited
normal ↔ Vector3
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
w double
getter/setter pair

Methods

clone() Plane
flip() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
splitPolygon(Polygon polygon, List<Polygon> coplanarFront, List<Polygon> coplanarBack, List<Polygon> front, List<Polygon> back) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromPoints(Vector3 a, Vector3 b, Vector3 c) Plane